/***************************** C HEADER FILE *********************************
**
**  Project:    Logic IO RTCU GPRS Gateway Protocol DLL
**  Filename:   GWPROT.H 
**  
******************************************************************************
**
** Definition of RACP2 data frame.
**
*****************************************************************************/
#ifndef _RACP2__H_
#define _RACP2__H_


/*****************************************************************************
**
**    MODULES USED 
**
*****************************************************************************/
#include "..\Modules\queue.h"


/*****************************************************************************
**
**    DEFINITIONS AND MACROS
**
*****************************************************************************/


/****************************************************************************
**
**    TYPEDEFS AND STRUCTURES
**
****************************************************************************/
#pragma pack(1)

struct racp2_header {
   unsigned long        src_id;                    // source ID of packet
   unsigned long        dst_id;                    // destination ID of packet
   unsigned short       crc;                       // CRC of the complete package (header+data)
   unsigned long        TNO;                       // transaction number
   unsigned short       data_len:10;               // bit  9.. 0  : Datalen (size of variable part) 
   unsigned short       channel:3;                 // bit 12..10  : Channel (0..7)
   unsigned short       gw_response:1;             // bit 13      : Gateway response.
   unsigned short       encrypt:1;                 // bit 14      : Data is encrypted
   unsigned short       compress:1;                // bit 15      : Data is compressed
   unsigned short       cmd_rc;                    // bit 14..0: Command / RC
};

struct racp2_packet {
   qnode                node;
   int                  type;                      // Always 1 (standard frame)
   struct racp2_header  hdr;
   unsigned char        data[GW_MAXDATASIZE_STD];  //Actual size is 'dataLen'.
};

struct ext_header {
   unsigned long        src_id;                    // source ID of packet
   unsigned long        dst_id;                    // destination ID of packet
   unsigned short       crc;                       // CRC of the complete package (header+data)
   unsigned long        TNO;                       // transaction number
   unsigned short       priority:2;                // bit  1.. 0  : Priority of the packet
   unsigned short       unack:1;                   // bit  2      : The packet generates no replies
   unsigned short       reserved1:5;               // bit  7.. 3  : Reserved for future use
   unsigned short       extpack:2;                 // bit  9.. 8  : Identify extended frame (always 1)
   unsigned short       channel:3;                 // bit 12..10  : Channel (0..7)
   unsigned short       gw_response:1;             // bit 13      : Gateway response.
   unsigned short       encrypt:1;                 // bit 14      : Data is encrypted
   unsigned short       compress:1;                // bit 15      : Data is compressed
   unsigned short       cmd_rc;                    // bit 14..0   : Command / RC
   unsigned short       reserved2;                 // Reserved for future use
   unsigned short       data_len;                  // Datalen (size of variable part) 
};

struct ext_packet {
   qnode                node;
   int                  type;                      // Always 2 (extended frame)
   struct ext_header    hdr;
   unsigned char        data[GW_MAXDATASIZE_EXT];  //Actual size is 'dataLen'.
};

#pragma pack()


/****************************************************************************
** 
**    EXPORTED VARIABLES
**
****************************************************************************/


/****************************************************************************
**
**    EXPORTED FUNCTIONS
**
****************************************************************************/


#endif /* _RACP2__H_ */
/****************************************************************************
**
**    EOF 
**
****************************************************************************/
